@@ -1,6 +1,7 @@
 /*
     SPDX-FileCopyrightText: 2020 MBition GmbH
     SPDX-FileContributor: Kai Uwe Broulik <kai_uwe.broulik@mbition.io>
+    SPDX-FileCopyrightText: 2023 Harald Sitter <sitter@kde.org>
 
     SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
@@ -12,6 +13,8 @@
 
 #include <libimobiledevice/libimobiledevice.h>
 
+class QFileSystemWatcher;
+
 namespace Solid
 {
 namespace Backends
@@ -35,7 +38,10 @@ public:
     void onDeviceEvent(const idevice_event_t *event);
 
 private:
+    void spinUp();
+    bool m_spunUp = false;
     QStringList m_deviceUdis;
+    std::unique_ptr<QFileSystemWatcher> m_watcher;
 };
 
 } // namespace IMobile
